==> mule-service-weave-2.8.2-rc1.jar: module-info.java <==
module org.mule.weave.mule.service.weave {
    requires java.base;
    requires java.sql;
    requires java.logging;
    requires org.mule.weave.runtime;
    requires org.mule.weave.wlang;
    requires org.mule.weave.module.java;
    requires org.mule.weave.module.core;
    requires org.mule.weave.module.yaml;
    requires org.mule.weave.module.ndjson;
    requires org.mule.weave.module.avro;
    requires org.mule.weave.module.jsonschema;
    requires org.mule.weave.module.xmlschema;
    requires org.mule.weave.module.dwb;
    requires org.mule.weave.mule.dwb.api;
    requires org.mule.weave.metadata.api;
    requires org.mule.runtime.api;
    requires org.mule.runtime.metadata.model.message;
    requires org.mule.runtime.metadata.model.api;
    requires org.mule.runtime.metadata.model.java;
    requires org.mule.runtime.metadata.model.json;
    requires org.mule.runtime.metadata.model.xml;

    exports org.mule.weave.v2.el;
    exports org.mule.weave.v2.el.provider;
    exports org.mule.weave.v2.el.metadata;
    exports org.mule.weave.v2.el.capabilities;
    exports org.mule.weave.v2.el.dwb;

    opens dw.mule.internal;
    opens org.mule.weave.v2.el.provider;
    opens org.mule.weave.v2.el.metadata;
    opens org.mule.weave.v2.el.capabilities;
    opens org.mule.weave.v2.el.dwb;

    provides NativeValueProvider with MuleNativeValueProvider;
    provides ValueToJavaAdapter with TypedValueToJavaAdapter;
    provides JavaValueMapper with MuleTypedValueMapper, CursorStreamProviderValueMapper, CursorIteratorProviderValueMapper, MultiMapValueMapper;
    provides ClassBeanDefinitionLookup with MuleMessageClassBeanDefinitionLookup, MuleApiClassBeanDefinitionLookup;
    provides JavaCustomConverter with FromCursorStreamProviderConverter, FromCursorIteratorProviderConverter, TypedValueConverter, ToCursorStreamProviderConverter;
    provides JavaWriterInterceptor with TypedValueInterceptor;

}

==> mule-service-weave-2.9.0-rc5.jar: module-info.java <==
module org.mule.weave.mule.service.weave {
    requires java.base;
    requires java.sql;
    requires java.logging;
    requires org.mule.weave.runtime;
    requires org.mule.weave.wlang;
    requires org.mule.weave.module.java;
    requires org.mule.weave.module.core;
    requires org.mule.weave.module.yaml;
    requires org.mule.weave.module.ndjson;
    requires org.mule.weave.module.avro;
    requires org.mule.weave.module.jsonschema;
    requires org.mule.weave.module.xmlschema;
    requires org.mule.weave.module.dwb;
    requires org.mule.weave.mule.dwb.api;
    requires org.mule.weave.metadata.api;
    requires org.mule.runtime.api;
    requires org.mule.runtime.metadata.model.message;
    requires org.mule.runtime.metadata.model.api;
    requires org.mule.runtime.metadata.model.java;
    requires org.mule.runtime.metadata.model.json;
    requires org.mule.runtime.metadata.model.xml;

    exports org.mule.weave.v2.el;
    exports org.mule.weave.v2.el.provider;
    exports org.mule.weave.v2.el.metadata;
    exports org.mule.weave.v2.el.capabilities;
    exports org.mule.weave.v2.el.dwb;

    opens dw.mule.internal;
    opens org.mule.weave.v2.el.provider;
    opens org.mule.weave.v2.el.metadata;
    opens org.mule.weave.v2.el.capabilities;
    opens org.mule.weave.v2.el.dwb;

    provides NativeValueProvider with MuleNativeValueProvider;
    provides ValueToJavaAdapter with TypedValueToJavaAdapter;
    provides JavaValueMapper with MuleTypedValueMapper, CursorStreamProviderValueMapper, CursorIteratorProviderValueMapper, MultiMapValueMapper;
    provides ClassBeanDefinitionLookup with MuleApiClassBeanDefinitionLookup;
    provides JavaCustomConverter with FromCursorStreamProviderConverter, FromCursorIteratorProviderConverter, TypedValueConverter, ToCursorStreamProviderConverter;
    provides JavaWriterInterceptor with TypedValueInterceptor;

}
